#
# spec file for package python-Theano
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-Theano
Version:        1.0.3
Release:        lp151.1.1
Summary:        A scientific python library
License:        BSD-3-Clause
Group:          Development/Libraries/Python
URL:            http://deeplearning.net/software/theano/
Source:         https://files.pythonhosted.org/packages/source/T/Theano/Theano-%{version}.tar.gz
Source1:        python-Theano.rpmlintrc
BuildRequires:  %{python_module setuptools}
BuildRequires:  c++_compiler
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-numpy >= 1.9.1
Requires:       python-scipy >= 0.14
Requires:       python-six >= 1.9.0
Requires:       c++_compiler
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module nose >= 1.3.0}
BuildRequires:  %{python_module numpy >= 1.9.1}
BuildRequires:  %{python_module parameterized}
BuildRequires:  %{python_module scipy >= 0.14}
BuildRequires:  %{python_module six >= 1.9.0}
# /SECTION
%python_subpackages

%description
Theano is a Python library that allows you to define, optimize, and
evaluate mathematical expressions involving multi-dimensional arrays.

Theano features:
* tight integration with numpy - Use numpy.ndarray in Theano-compiled
  functions.
* transparent use of a GPU - Perform data-intensive calculations up to
  140x faster than with CPU. (float32 only)
* symbolic differentiation - Let Theano do your derivatives.
* speed and stability optimizations – Get the right answer for log(1+x)
  even when x is really tiny.
* dynamic C code generation - Evaluate expressions faster.
* extensive unit-testing and self-verification – Detect and diagnose
  many types of mistake.

%prep
%setup -q -n Theano-%{version}

%build
%python_build

%install
%python_install

# replace duplicate .pyo/.pyc with hardlinks
%python_expand %fdupes %{buildroot}%{_defaultdocdir}/%{name}
%python_expand %fdupes %{buildroot}%{$python_sitelib}

# Fix python-bytecode-inconsistent-mtime
%python_expand $python -m compileall -d %{$python_sitelib} %{buildroot}%{$python_sitelib}/theano
%python_expand $python -O -m compileall -d %{$python_sitelib}  %{buildroot}%{$python_sitelib}/theano

%files %{python_files}
%doc DESCRIPTION.txt EMAIL.txt HISTORY.txt NEWS.txt README.rst
%license doc/LICENSE.txt
%python3_only %{_bindir}/theano-cache
%python3_only %{_bindir}/theano-nose
%{python_sitelib}/bin
%{python_sitelib}/theano
%{python_sitelib}/Theano-%{version}-*.egg-info

%changelog
* Sun Dec 17 2017 arun@gmx.de
- converted to single spec:
  + added obsolete for python2
  + install binaries as python3_only
  + use of rpm-macros for 2&3
* Sat Feb 11 2017 toddrme2178@gmail.com
- Fix source URL
- Add license and basic doc files
- Implement update-alternatives
* Tue Aug 23 2016 jmatejek@suse.com
- update to 0.8.2
  * improved source packaging
  * renewed development
  * python2/3 compatibility
  * performance improvements
  * new GPU backends
- dropped doc subpackage as the source is no longer configured
  to rebuild the docs
- cleared out Requires and BuildRequires list
- do not delete first line of every .py file (fixes boo#994408)
* Sat Jul 26 2014 scorot@free.fr
- version 0.6.0 git 20140726
  * Many updates and bug fixes since 0.5.0, for a full list of
    changes see https://pypi.python.org/pypi/Theano/
- package is now noarch except for SLE 11
- update rpmlintrc file
* Thu Oct 24 2013 speilicke@suse.com
- Require python-setuptools instead of distribute (upstreams merged)
* Wed Jun 20 2012 scorot@free.fr
- fix wrong characters in package description
* Wed Jun 20 2012 scorot@free.fr
- rename package to match the upstream name an modify spec file
  accordingly
- fix bytecode mtime inconsistency
* Sun Jun 17 2012 scorot@free.fr
- do not define %%%%DOCDIR but use %%%%_defaultdocdir instead
- update to git snapshot 20120617
  * No changelog available
* Sun Jun 17 2012 scorot@free.fr
- spec file cleanup
- do not require nvidia-cuda-toolkit
* Sun May 13 2012 scorot@free.fr
- spec file cleanup
- checkout upstream git 20120513
* Sat Feb 18 2012 scorot@free.fr
- update to version 0.5.0.git20120218
